@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  *
@@ -20,10 +20,18 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
+//
+//	Includes
+//
+
 #include <IOKit/IOLib.h>
 #include <IOKit/storage/IOBlockStorageDriver.h>
 #include "IOUFIStorageServices.h"
 
+//
+//	Macros
+//
+
 
 #if ( SCSI_BLOCK_SERVICES_DEBUGGING_LEVEL >= 1 )
 #define PANIC_NOW(x)		IOPanic x
@@ -69,8 +77,10 @@ typedef struct BlockServicesClientData	BlockServicesClientData;
 #define super IOBlockStorageDevice
 OSDefineMetaClassAndStructors ( IOUFIStorageServices, IOBlockStorageDevice );
 
-//---------------------------------------------------------------------------
-// attach to provider.
+
+//
+//	 attach - attach to provider.									[PROTECTED]
+//
 
 bool
 IOUFIStorageServices::attach( IOService * provider )
@@ -82,7 +92,7 @@ IOUFIStorageServices::attach( IOService * provider )
 		return false;
 	}
 	
-	fProvider = OSDynamicCast ( IOUSBMassStorageUFISubclass, provider );
+	fProvider = OSDynamicCast ( IOUSBMassStorageUFIDevice, provider );
 	if ( fProvider == NULL )
 	{
 		ERROR_LOG ( ( "IOUFIStorageServices: attach; wrong provider type!\n" ) );
@@ -103,8 +113,9 @@ IOUFIStorageServices::attach( IOService * provider )
 }
 
 
-//---------------------------------------------------------------------------
-// detach from provider.
+//
+//	 detach - detach from provider.								[PROTECTED]
+//
 
 void
 IOUFIStorageServices::detach( IOService * provider )
@@ -117,8 +128,9 @@ IOUFIStorageServices::detach( IOService * provider )
 }
 
 
-//---------------------------------------------------------------------------
-// message
+//
+//	 message - handles messages.									   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::message( 	UInt32 			type,
@@ -153,8 +165,9 @@ IOUFIStorageServices::message( 	UInt32 			type,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 AsyncReadWriteComplete - Completion routine for I/O	  [STATIC][PRIVATE]
+//
 
 void 
 IOUFIStorageServices::AsyncReadWriteComplete(	void * 			clientData,
@@ -211,8 +224,10 @@ IOUFIStorageServices::AsyncReadWriteComplete(	void * 			clientData,
 	}
 }
 
-//---------------------------------------------------------------------------
-// 
+
+//
+//	 doAsyncReadWrite												   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::doAsyncReadWrite (	IOMemoryDescriptor *	buffer,
@@ -279,7 +294,9 @@ IOUFIStorageServices::doAsyncReadWrite (	IOMemoryDescriptor *	buffer,
 	return requestStatus;
 }
 
-//---------------------------------------------------------------------------
+
+//
+//	 doSyncReadWrite												   [PUBLIC]
 //
 
 IOReturn
@@ -310,8 +327,9 @@ IOUFIStorageServices::doSyncReadWrite(		IOMemoryDescriptor * 	buffer,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 doEjectMedia													   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::doEjectMedia( void )
@@ -341,8 +359,9 @@ IOUFIStorageServices::doEjectMedia( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 doFormatMedia													   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::doFormatMedia( UInt64 byteCapacity )
@@ -371,8 +390,9 @@ IOUFIStorageServices::doFormatMedia( UInt64 byteCapacity )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 doGetFormatCapacities											   [PUBLIC]
+//
 
 UInt32
 IOUFIStorageServices::doGetFormatCapacities(	UInt64 * capacities,
@@ -401,8 +421,9 @@ IOUFIStorageServices::doGetFormatCapacities(	UInt64 * capacities,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 doLockUnlockMedia												   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::doLockUnlockMedia ( bool doLock )
@@ -417,7 +438,8 @@ IOUFIStorageServices::doLockUnlockMedia ( bool doLock )
 }
 
 
-//---------------------------------------------------------------------------
+//
+//	 doSynchronizeCache											   [PUBLIC]
 //
 
 IOReturn
@@ -433,8 +455,9 @@ IOUFIStorageServices::doSynchronizeCache ( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 getVendorString												   [PUBLIC]
+//
 
 char *
 IOUFIStorageServices::getVendorString ( void )
@@ -443,8 +466,9 @@ IOUFIStorageServices::getVendorString ( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 getProductString												   [PUBLIC]
+//
 
 char *
 IOUFIStorageServices::getProductString ( void )
@@ -453,8 +477,9 @@ IOUFIStorageServices::getProductString ( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 getRevisionString												   [PUBLIC]
+//
 
 char *
 IOUFIStorageServices::getRevisionString ( void )
@@ -463,8 +488,9 @@ IOUFIStorageServices::getRevisionString ( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 getAdditionalDeviceInfoString									   [PUBLIC]
+//
 
 char *
 IOUFIStorageServices::getAdditionalDeviceInfoString ( void )
@@ -474,8 +500,9 @@ IOUFIStorageServices::getAdditionalDeviceInfoString ( void )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportBlockSize												   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportBlockSize ( UInt64 * blockSize )
@@ -485,8 +512,9 @@ IOUFIStorageServices::reportBlockSize ( UInt64 * blockSize )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportEjectability											   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportEjectability ( bool * isEjectable )
@@ -496,8 +524,9 @@ IOUFIStorageServices::reportEjectability ( bool * isEjectable )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportLockability												   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportLockability ( bool * isLockable )
@@ -507,8 +536,9 @@ IOUFIStorageServices::reportLockability ( bool * isLockable )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportPollRequirements										   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportPollRequirements ( 	bool * pollIsRequired,
@@ -521,8 +551,9 @@ IOUFIStorageServices::reportPollRequirements ( 	bool * pollIsRequired,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportMaxReadTransfer											   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportMaxReadTransfer ( UInt64 		blockSize,
@@ -542,8 +573,9 @@ IOUFIStorageServices::reportMaxReadTransfer ( UInt64 		blockSize,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportMaxValidBlock											   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportMaxValidBlock ( UInt64 * maxBlock )
@@ -553,8 +585,9 @@ IOUFIStorageServices::reportMaxValidBlock ( UInt64 * maxBlock )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportMaxWriteTransfer										   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportMaxWriteTransfer ( 	UInt64		blockSize,
@@ -574,8 +607,9 @@ IOUFIStorageServices::reportMaxWriteTransfer ( 	UInt64		blockSize,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportMediaState												   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportMediaState ( 	bool * mediaPresent,
@@ -595,8 +629,9 @@ IOUFIStorageServices::reportMediaState ( 	bool * mediaPresent,
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportRemovability											   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportRemovability ( bool * isRemovable )
@@ -606,8 +641,9 @@ IOUFIStorageServices::reportRemovability ( bool * isRemovable )
 }
 
 
-//---------------------------------------------------------------------------
-// 
+//
+//	 reportWriteProtection											   [PUBLIC]
+//
 
 IOReturn
 IOUFIStorageServices::reportWriteProtection ( bool * isWriteProtected )
